@@ -13,8 +13,9 @@
 */
 #define _FILE_OFFSET_BITS 64
 #define _LARGE_FILES  
+#define _DEFAULT_SOURCE 1  /* New name for SVID & BSD source defines */
 #define _BSD_SOURCE 1      /* Make sure strdup() is in string.h */
-#define _XOPEN_SOURCE 600  /* Make sure strdup() is in string.h */
+#define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
 
 #include <string.h>
 #include <limits.h>
@@ -23,9 +24,10 @@
 
 #include <math.h>
 
-#include "pm_c_util.h"
-#include "mallocvar.h"
-#include "nstring.h"
+#include "netpbm/pm_c_util.h"
+#include "netpbm/mallocvar.h"
+#include "netpbm/nstring.h"
+
 #include "pam.h"
 #include "ppm.h"
 #include "libpbm.h"
@@ -225,7 +227,7 @@ allocPamRow(const struct pam * const pamP) {
 
     overflow_add(sizeof(tuple *), bytesPerTuple);
     tuplerow = malloc2(pamP->width, (sizeof(tuple *) + bytesPerTuple));
-                      
+
     if (tuplerow != NULL) {
         /* Now we initialize the pointers to the individual tuples
            to make this a regulation C two dimensional array.  
@@ -784,8 +786,8 @@ validateMinDepth(const struct pam * const pamP,
 static void
 interpretTupleType(struct pam * const pamP) {
 /*----------------------------------------------------------------------------
-   Fill in redundant convenience fields in *pamP with information implied by
-   the pamP->tuple_type implies:
+   Fill in redundant convenience fields in *pamP with information the
+   pamP->tuple_type value implies:
 
      visual
      colorDepth
